@@ -5,13 +5,11 @@ from scipy.stats import PearsonRConstantInputWarning
 from sklearn.preprocessing import StandardScaler
 import numpy as np
 import scipy as sp
-import scipy.stats
 import time
 from pathlib import Path
 
 from movado.estimator import Estimator
 from movado.mab_handler import MabHandler
-import warnings
 
 
 class Controller(ABC):
@@ -21,7 +19,10 @@ class Controller(ABC):
         exact_fitness: Callable[[List[float]], List[float]],
         estimator: Estimator,
         self_exact: Optional[object] = None,
-        debug=False,
+        problem_dimensionality: int = -1,
+        solutions: List[List[List[float]]] = None,
+        debug: bool = False,
+        **kwargs
     ):
         self.__scaler = StandardScaler()
         self.__time_dataset: List[float] = []
@@ -38,7 +39,7 @@ class Controller(ABC):
             Path(self._controller_debug).open("w").close()
 
     @abstractmethod
-    def compute_objective(self, point: List[int]) -> float:
+    def compute_objective(self, point: List[int]) -> List[float]:
         pass
 
     def _compute_exact(
@@ -159,19 +160,39 @@ class Controller(ABC):
 
     def get_time_error_correlation(self):
         try:
+            samples = len(self.__error_dataset)
+            independent_vars = 2
             if (
                 self.__is_constant(self.__error_dataset)
                 or self.__is_constant(self.__time_dataset)
                 or self.__is_constant(self.__cost_dataset)
+                or samples - independent_vars == 1
             ):
                 return 0
-            time_correlation = sp.stats.pearsonr(
+            time_cost_correlation: float = sp.stats.pearsonr(
                 self.__time_dataset, self.__cost_dataset
             )[0]
-            error_correlation = sp.stats.pearsonr(
+            error_cost_correlation: float = sp.stats.pearsonr(
                 self.__error_dataset, self.__cost_dataset
             )[0]
-            return np.abs(time_correlation - error_correlation)
+            time_error_correlation: float = sp.stats.pearsonr(
+                self.__time_dataset, self.__error_dataset
+            )[0]
+            R2 = np.sqrt(
+                (
+                    np.abs(time_cost_correlation ** 2)
+                    + np.abs(error_cost_correlation ** 2)
+                    - 2
+                    * time_cost_correlation
+                    * error_cost_correlation
+                    * time_error_correlation
+                )
+                / (1 - np.abs(time_error_correlation))
+            )
+            R2_adj = 1 - (
+                ((1 - R2 ** 2) * (samples - 1)) / (samples - independent_vars - 1)
+            )
+            return -R2_adj
         except ValueError:
             return 0
 
